const chartMainDefault = (divId) => {
    return {
        tooltip: {
            trigger: 'item'
        },
        backgroundColor: 'transparent',
        legend: {
            orient: 'horizontal',
            left: 'left'
        },
        grid: {
            show: true,
            backgroundColor: 'transparent',
            borderWidth: 0
        },
        dataset: [
            {
                id: 'raw',
                dimensions: ['source', 'catogary', 'jh', 'requestTime', 'bjsj',
                    'jcsj', 'fssj', 'bjnr', 'clfs', 'sssj', 'dsjs', 'zjzh'],
                source: []
            }, {
                id: 'left',
                fromDatasetId: 'raw',
                transform: [
                    {
                        type: 'ecSimpleTransform:aggregate',
                        config: {
                            resultDimensions: [
                                { from: 'source' },
                                { name: 'c1', from: 'catogary', method: 'count' }
                            ],
                            groupBy: 'source'
                        }
                    }
                ]
            }
        ],
        series: [
            {
                datasetIndex: 1,
                name: '数据来源',
                type: 'pie',
                radius: ['30%', '60%'],
                avoidLabelOverlap: false,
                itemStyle: {
                    borderRadius: 10,
                    borderColor: '#fff',
                    borderWidth: 2
                },
                label: {
                    alignTo: 'edge',
                    formatter: '{name|{b}}\n{time|{@c1} 项}',
                    minMargin: 5,
                    edgeDistance: 10,
                    lineHeight: 15,
                    rich: {
                        time: {
                            fontSize: 12,
                            color: 'resultDimensions'
                        }
                    }
                },
                labelLine: {
                    length: 15,
                    length2: 0,
                    maxSurfaceAngle: 80
                },
                labelLayout: function (params) {
                    const isLeft = params.labelRect.x < document.getElementById(divId).offsetWidth / 2;
                    const points = params.labelLinePoints;
                    points[2][0] = isLeft
                        ? params.labelRect.x
                        : params.labelRect.x + params.labelRect.width;
                    return {
                        labelLinePoints: points
                    };
                },
                emphasis: {
                    label: {
                        show: true,
                        fontSize: '16',
                        fontWeight: 'bold'
                    }
                },
                labelLine: {
                    show: true
                },
                encode: {
                    itemName: 'source',
                    value: 'c1'
                }
            }
        ]
    }
}

function subChartToolFeature (subChart) {
    return {
        myDynamicBar: {
            title: '动态排序柱状图',
            icon: 'path://M432.45,595.444c0,2.177-4.661,6.82-11.305,6.82c-6.475,0-11.306-4.567-11.306-6.82s4.852-6.812,11.306-6.812C427.841,588.632,432.452,593.191,432.45,595.444L432.45,595.444z M421.155,589.876c-3.009,0-5.448,2.495-5.448,5.572s2.439,5.572,5.448,5.572c3.01,0,5.449-2.495,5.449-5.572C426.604,592.371,424.165,589.876,421.155,589.876L421.155,589.876z M421.146,591.891c-1.916,0-3.47,1.589-3.47,3.549c0,1.959,1.554,3.548,3.47,3.548s3.469-1.589,3.469-3.548C424.614,593.479,423.062,591.891,421.146,591.891L421.146,591.891zM421.146,591.891',
            onclick: function () {
                if (subChart.chartType !== 'hBar') {
                    subChart.chartType = 'hBar'
                    subChart.chart.showLoading('正在切换')
                    subChart.chart.setOption(chartSubDefault(subChart,
                        subChart.chart.getOption().dataset[0].source), true)
                    subChart.chart.hideLoading()
                    subMediaQuery(null, subChart)
                }
            }
        },
        myBar: {
            show: true,
            title: '分类柱状图',
            icon: 'path://M121.488231,0 L102.050114,0 C99.36627,-1.1969592e-16 97.1905846,2.17568537 97.1905846,4.85952929 L97.1905846,133.140471 C97.1905846,135.824315 99.36627,138 102.050114,138 L121.488231,138 C124.172075,138 126.34776,135.824315 126.34776,133.140471 L126.34776,4.85952929 C126.34776,2.17568537 124.172075,1.1969592e-16 121.488231,0 Z M170.083523,30.1571753 L150.645406,30.1571753 C147.961562,30.1571753 145.785877,32.3328607 145.785877,35.0167046 L145.785877,132.207289 C145.785877,134.891133 147.961562,137.066819 150.645406,137.066819 L170.083523,137.066819 C172.767367,137.066819 174.943052,134.891133 174.943052,132.207289 L174.943052,35.0167046 C174.943052,32.3328607 172.767367,30.1571753 170.083523,30.1571753 Z M53.4548215,39.8762339 C50.7709777,39.876234 48.5952924,42.0519193 48.5952924,44.7357631 L48.5952924,132.207289 C48.5952924,134.891133 50.7709777,137.066818 53.4548215,137.066819 L72.8929386,137.066819 C75.5767824,137.066818 77.7524677,134.891133 77.7524677,132.207289 L77.7524677,44.7357631 C77.7524676,42.0519193 75.5767824,39.876234 72.8929386,39.8762339 L53.4548215,39.8762339 Z M29.1571753,67.17388 L29.1571753,132.207289 C29.1571753,134.891133 26.9814901,137.066818 24.2976462,137.066819 L4.85952929,137.066819 C2.17568537,137.066819 3.28676086e-16,134.891133 0,132.207289 L0,67.17388 C7.33863613e-08,64.4900361 2.17568542,62.3143508 4.85952929,62.3143508 L24.2976462,62.3143508 C26.98149,62.3143509 29.1571753,64.4900362 29.1571753,67.17388 Z',
            onclick: function () {
                if (subChart.chartType !== 'vBar') {
                    subChart.chartType = 'vBar'
                    subChart.chart.showLoading('正在切换')
                    subChart.chart.setOption(chartSubVBar(subChart,
                        subChart.chart.getOption().dataset[0].source), true)
                    subChart.chart.hideLoading()
                }
            }
        },
        myPie: {
            show: true,
            title: '饼图',
            icon: 'path://M72.1778824,12.9606446 L72.1778824,73.6462877 C72.1779317,75.129331 72.9386663,76.5065116 74.1881954,77.2856176 C75.4377246,78.0647237 76.9977039,78.1345538 78.3105882,77.4701504 L128.354824,52.1402676 L132.666353,49.9503148 C134.757503,48.8920984 137.302156,49.7461658 138.350118,51.857969 L138.468706,52.1060495 L138.782118,52.8930638 C140.942118,58.6416896 144,65.8873535 144,83.8518095 C144,116.316148 115.123765,152.612903 73.2282353,152.612903 C31.3242354,152.612903 0,119.994584 0,80.8406245 C0,44.5353146 27.216,13.7391044 62.2588236,9.22232682 C64.122353,8.98280072 65.9265883,8.80315611 67.6715294,8.69194766 C68.8395088,8.61630135 69.986418,9.03213213 70.8400527,9.84074781 C71.6936873,10.6493635 72.1779411,11.7786714 72.1778824,12.9606446 Z M90.0254118,0.659269609 C88.9814749,0.488081123 87.9163292,0.795987208 87.1201941,1.49909291 C86.324059,2.20219861 85.8798887,3.22724309 85.9087059,4.29493319 L85.9087059,54.6039644 C85.9087059,56.9393437 87.6028236,57.8717845 89.5680001,56.7511446 L133.149176,31.9088684 C134.092985,31.4117209 134.762111,30.50855 134.968019,29.4538349 C135.173928,28.3991197 134.894328,27.3070442 134.208,26.4853136 C134.208,26.4853136 133.538824,25.5357637 132.446118,24.3381334 C127.296,18.6921614 122.832,14.7399812 116.860235,10.9417819 C109.345997,6.07770841 100.978781,2.71218494 92.2108235,1.0271132 C89.9745882,0.599388123 90.0254118,0.659269609 90.0254118,0.659269609 L90.0254118,0.659269609 Z',
            onclick: function () {
                if (subChart.chartType !== 'pie') {
                    subChart.chartType = 'pie'
                    subChart.chart.showLoading('正在切换')
                    subChart.chart.setOption(chartSubPie(subChart,
                        subChart.chart.getOption().dataset[0].source), true)
                    subChart.chart.hideLoading()
                }
            }
        }
    }
}
const chartSubDefault = (subChart, dataList) => {
    return {
        toolbox: {
            show: true,
            feature: subChartToolFeature(subChart)
        },
        dataset: [
            {
                id: 'raw',
                dimensions: ['source', 'catogary', 'jh', 'requestTime', 'bjsj',
                    'jcsj', 'fssj', 'bjnr', 'clfs', 'sssj', 'dsjs', 'zjzh'],
                source: dataList
            }, {
                id: 'right',
                fromDatasetId: 'raw',
                transform: [
                    {
                        type: 'filter',
                        config: {
                            dimension: 'source',
                            '=': !subChart.sourceKey ? '' : subChart.sourceKey
                        }
                    },
                    {
                        type: 'ecSimpleTransform:aggregate',
                        config: {
                            resultDimensions: [
                                { from: 'catogary' },
                                { name: 'c1', from: 'source', method: 'count' }
                            ],
                            groupBy: 'catogary'
                        }
                    },
                    {
                        type: 'sort',
                        config: {
                            dimension: 'c1',
                            order: 'desc'
                        }
                    }
                ]
            }
        ],
        xAxis: {
            type: 'value',
            minInterval: 1,
            max: function (value) {
                if (value.max && value.max < 8) {
                    return 8
                } else {
                    const r = _.floor(value.max * 1.2)
                    return _.ceil(r / 5.0) * 5
                }
            }
        },
        yAxis: {
            type: 'category',
            inverse: true,
            animationDuration: 300,
            animationDurationUpdate: 300,
            axisLabel: {
                show: false
            }
        },
        series: [
            {
                datasetIndex: 1,
                id: 'rightChart',
                type: 'bar',
                label: {
                    show: true,
                    formatter: '{b}({c})'
                },
                encode: {
                    x: 'c1',
                    y: 'catogary'
                }
            }
        ],
        backgroundColor: 'transparent'
    }
}
const chartSubVBar = (subChart, dataList) => {
    return {
        toolbox: {
            show: true,
            feature: subChartToolFeature(subChart)
        },
        dataset: [
            {
                id: 'raw',
                dimensions: ['source', 'catogary', 'jh', 'requestTime', 'bjsj',
                    'jcsj', 'fssj', 'bjnr', 'clfs', 'sssj', 'dsjs', 'zjzh'],
                source: dataList
            }, {
                id: 'right',
                fromDatasetId: 'raw',
                transform: [
                    {
                        type: 'filter',
                        config: {
                            dimension: 'source',
                            '=': !subChart.sourceKey ? '' : subChart.sourceKey
                        }
                    },
                    {
                        type: 'ecSimpleTransform:aggregate',
                        config: {
                            resultDimensions: [
                                { from: 'catogary' },
                                { name: 'c1', from: 'source', method: 'count' }
                            ],
                            groupBy: 'catogary'
                        }
                    },
                    {
                        type: 'sort',
                        config: {
                            dimension: 'c1',
                            order: 'desc'
                        }
                    }
                ]
            }
        ],
        yAxis: {
            type: 'value',
            minInterval: 1,
            max: function (value) {
                if (value.max && value.max < 8) {
                    return 8
                } else {
                    const r = _.floor(value.max * 1.2)
                    return _.ceil(r / 5.0) * 5
                }
            }
        },
        xAxis: {
            type: 'category',
            inverse: true,
            animationDuration: 300,
            animationDurationUpdate: 300,
            axisLabel: {
                show: true
            }
        },
        series: [
            {
                datasetIndex: 1,
                id: 'rightChartVBar',
                type: 'bar',
                label: {
                    show: true,
                    formatter: ' {@c1}',
                    position: 'top'
                },
                encode: {
                    x: 'catogary',
                    y: 'c1'
                }
            }
        ]
    }
}
const chartSubPie = (subChart, dataList) => {
    return {
        toolbox: {
            show: true,
            feature: subChartToolFeature(subChart)
        },
        dataset: [
            {
                id: 'raw',
                dimensions: ['source', 'catogary', 'jh', 'requestTime', 'bjsj',
                    'jcsj', 'fssj', 'bjnr', 'clfs', 'sssj', 'dsjs', 'zjzh'],
                source: dataList
            }, {
                id: 'right',
                fromDatasetId: 'raw',
                transform: [
                    {
                        type: 'filter',
                        config: {
                            dimension: 'source',
                            '=': !subChart.sourceKey ? '' : subChart.sourceKey
                        }
                    },
                    {
                        type: 'ecSimpleTransform:aggregate',
                        config: {
                            resultDimensions: [
                                { from: 'catogary' },
                                { name: 'c1', from: 'source', method: 'count' }
                            ],
                            groupBy: 'catogary'
                        }
                    },
                    {
                        type: 'sort',
                        config: {
                            dimension: 'c1',
                            order: 'desc'
                        }
                    }
                ]
            }
        ],
        series: [
            {
                datasetIndex: 1,
                id: 'rightChartPie',
                type: 'pie',
                label: {
                    show: true,
                    formatter: '{b}({@c1})'
                },
                radius: ['30%', '60%'],
                avoidLabelOverlap: false,
                itemStyle: {
                    borderRadius: 10,
                    borderColor: '#fff',
                    borderWidth: 2
                },
                encode: {
                    value: 'c1',
                    itemName: 'catogary'
                }
            }
        ]
    }
}

const mediaChangedOption = (fitIndex, chartMain, chartSub) => {
    mainMediaQuery(fitIndex, chartMain.chart)
    subMediaQuery(fitIndex, chartSub)
}
function mainMediaQuery (fitIndex, chart) {
    const keys = ['xxl', 'xl', 'lg', 'md', 'sm', 'xs']
    if (fitIndex <= keys.indexOf('lg')) {
        chart.setOption({ legend: { show: true, orient: 'vertical' } })
    } else if (fitIndex <= keys.indexOf('md')) {
        chart.setOption({ legend: { show: true, orient: 'horizontal' } })
    } else {
        chart.setOption({ legend: { show: false } })
    }
}
function subMediaQuery (fitIndex, chartSub) {
    const breakPoints = { xxl: 1600, xl: 1200, lg: 992, md: 768, sm: 458, xs: -1 }
    const keys = Object.keys(breakPoints)
    if (!fitIndex) {
        fitIndex = -1
        const width = chartSub.container.offsetWidth
        for (var p in breakPoints) {
            fitIndex++
            if (width >= breakPoints[p]) {
                break
            }
        }
    }

    if (chartSub.chartType === 'hBar') {
        if (fitIndex <= keys.indexOf('lg')) {
            chartSub.chart.setOption({
                toolbox: { show: true },
                yAxis: { axisLabel: { show: true } },
                series: { id: 'rightChart', label: { formatter: '{@c1}' } }
            })
        } else if (fitIndex <= keys.indexOf('md')) {
            chartSub.chart.setOption({
                toolbox: { show: true },
                yAxis: { axisLabel: { show: false } },
                series: { id: 'rightChart', label: { formatter: '{b}({@c1})' } }
            })
        } else {
            chartSub.chart.setOption({
                toolbox: { show: true },
                yAxis: { axisLabel: { show: false } },
                series: { id: 'rightChart', label: { formatter: '{b}({@c1})' } }
            })
        }
    } else if (chartSub.chartType === 'vBar') {
    } else if (chartSub.chartType === 'Pie') {
    }
}

export default {
    chartMainDefault,
    chartSubDefault,
    mediaChangedOption
}